package com.sf.vertx.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson2.JSONObject;
import com.sf.vertx.api.pojo.AppConfig;
import com.sf.vertx.api.pojo.VertxConfig;
import com.sf.vertx.constans.RedisKeyConfig;
import com.sf.vertx.handle.AppConfigHandle;
import com.sf.vertx.service.AppConfigService;

import lombok.extern.slf4j.Slf4j;

@Slf4j
@Service
public class AppConfigServiceImpl implements AppConfigService {
	@Value("${server.vertx.environment}")
	private String vertxEnvironment;
	@Autowired
	private RedisTemplate<String, String> redisTemplate;

	/***
	 * 新增、修改
	 * 
	 * @param appConfig
	 */
	public void saveAppConfig(AppConfig appConfig) {
		redisTemplate.opsForZSet().add(RedisKeyConfig.APP_CONFIG_SET_KEY, appConfig.getAppCode(), 0);
		String appCodeKey = RedisKeyConfig.APP_CONFIG_PREFIX_KEY + ":" + appConfig.getAppCode();
		redisTemplate.opsForValue().set(appCodeKey, JSONObject.toJSONString(appConfig));

		// 初始化AppConfig本地缓存
		AppConfigHandle.initAppConfig(redisTemplate, appConfig.getAppCode(), true);

	}

	/***
	 * 删除
	 * 
	 * @param appConfig
	 */
	public void deleteAppConfig(AppConfig appConfig) {
		redisTemplate.opsForZSet().remove(RedisKeyConfig.APP_CONFIG_SET_KEY, appConfig.getAppCode());
		String appCodeKey = RedisKeyConfig.APP_CONFIG_PREFIX_KEY + ":" + appConfig.getAppCode();
		redisTemplate.delete(appCodeKey);
		
		// 禁用本地缓存
		AppConfigHandle.addDisabledAppcode(appConfig.getAppCode());
	}

	/***
	 * 新增、修改
	 * 
	 * @param appConfig
	 */
	public void saveVertxConfig(VertxConfig vertxConfig) {
		String vertxConfigKey = RedisKeyConfig.VERTX_CONFIG_STRING_KEY;
		redisTemplate.opsForValue().set(vertxConfigKey, JSONObject.toJSONString(vertxConfig));
		AppConfigHandle.initVertxConfig(redisTemplate);
	}

}
